@@ -1,5 +1,6 @@
 
-
+import com.beust.kobalt.plugin.java.javaCompiler
+import com.beust.kobalt.plugin.osgi.osgi
 import com.beust.kobalt.plugin.packaging.assemble
 import com.beust.kobalt.plugin.publish.bintray
 import com.beust.kobalt.project
@@ -12,7 +13,8 @@ val jcommander = project {
     name = "jcommander"
     group = "com.beust"
     artifactId = name
-    version = "1.63"
+    version = "1.78"
+    description = "A Java library to parse command line options"
 
     dependenciesTest {
         compile("org.testng:testng:6.10")
@@ -29,6 +31,12 @@ val jcommander = project {
         sign = true
     }
 
+    javaCompiler {
+        args("-target", "1.8", "-source", "1.8", "-g", "-encoding", "utf-8")
+    }
+
+    osgi {}
+
     pom = Model().apply {
         name = project.name
         description = "Command line parsing"
