@@ -22,6 +22,7 @@ import kotlin.reflect.jvm.internal.impl.builtins.JvmBuiltInClassDescriptorFactor
 import kotlin.reflect.jvm.internal.impl.builtins.KotlinBuiltIns
 import kotlin.reflect.jvm.internal.impl.descriptors.*
 import kotlin.reflect.jvm.internal.impl.descriptors.annotations.AnnotationDescriptorImpl
+import kotlin.reflect.jvm.internal.impl.descriptors.annotations.Annotations
 import kotlin.reflect.jvm.internal.impl.descriptors.annotations.AnnotationsImpl
 import kotlin.reflect.jvm.internal.impl.descriptors.annotations.createDeprecatedAnnotation
 import kotlin.reflect.jvm.internal.impl.descriptors.impl.ClassDescriptorImpl
@@ -81,10 +82,9 @@ open class JvmBuiltInsSettings(
         ).let { AnnotationsImpl(listOf(it)) }
     }
 
-    private val notSupportedDeprecation by storageManager.createLazyValue {
-        // We use both LowPriorityInOverloadResolution to achieve the following goals:
-        // - If there is something to resolve to beside an additional built-in member, it's *almost* always will win
-        // - Otherwise error will be reported because of Deprecated annotation with Error level
+    private val lowPriorityAnnotation: Annotations by storageManager.createLazyValue {
+        // We use both LowPriorityInOverloadResolution to achieve the following goal:
+        // If there is something to resolve to beside an additional built-in member, it's *almost* always will win
         val lowPriorityAnnotation =
                 ClassDescriptorImpl(
                         moduleDescriptor.getPackage(LOW_PRIORITY_IN_OVERLOAD_RESOLUTION_FQ_NAME.parent()), LOW_PRIORITY_IN_OVERLOAD_RESOLUTION_FQ_NAME.shortName(),
@@ -95,12 +95,7 @@ open class JvmBuiltInsSettings(
                     AnnotationDescriptorImpl(defaultType, emptyMap(), SourceElement.NO_SOURCE)
                 }
 
-        val errorDeprecation = moduleDescriptor.builtIns.createDeprecatedAnnotation(
-                "This member is not supported by Kotlin compiler on this language level",
-                level = DeprecationLevel.ERROR.name
-        )
-
-        AnnotationsImpl(listOf(lowPriorityAnnotation, errorDeprecation))
+        AnnotationsImpl(listOf(lowPriorityAnnotation))
     }
 
     private fun StorageManager.createMockJavaIoSerializableType(): KotlinType {
@@ -162,7 +157,7 @@ open class JvmBuiltInsSettings(
 
                     JDKMemberStatus.NOT_CONSIDERED -> {
                         if (!isAdditionalBuiltInsFeatureSupported) {
-                            setAdditionalAnnotations(notSupportedDeprecation)
+                            setAdditionalAnnotations(lowPriorityAnnotation)
                         }
                         else {
                             setAdditionalAnnotations(notConsideredDeprecation)
@@ -173,7 +168,7 @@ open class JvmBuiltInsSettings(
 
                     JDKMemberStatus.WHITE_LIST -> {
                         if (!isAdditionalBuiltInsFeatureSupported) {
-                            setAdditionalAnnotations(notSupportedDeprecation)
+                            setAdditionalAnnotations(lowPriorityAnnotation)
                         }
                     }
                 }
@@ -321,7 +316,7 @@ open class JvmBuiltInsSettings(
                 setSubstitution(substitutor.substitution)
 
                 if (!isAdditionalBuiltInsFeatureSupported) {
-                    setAdditionalAnnotations(notSupportedDeprecation)
+                    setAdditionalAnnotations(lowPriorityAnnotation)
                 }
                 else if (SignatureBuildingComponents.signature(javaAnalogueDescriptor, javaConstructor.computeJvmDescriptor()) !in WHITE_LIST_CONSTRUCTOR_SIGNATURES) {
                     setAdditionalAnnotations(notConsideredDeprecation)
@@ -333,6 +328,8 @@ open class JvmBuiltInsSettings(
 
     override fun isFunctionAvailable(classDescriptor: DeserializedClassDescriptor, functionDescriptor: SimpleFunctionDescriptor): Boolean {
         if (!functionDescriptor.annotations.hasAnnotation(PLATFORM_DEPENDENT_ANNOTATION_FQ_NAME)) return true
+        if (!isAdditionalBuiltInsFeatureSupported) return false
+
         val javaAnalogueClassDescriptor = classDescriptor.getJavaAnalogue() ?: return true
 
         val jvmDescriptor = functionDescriptor.computeJvmDescriptor()
